#
# spec file for package netperfmeter
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           netperfmeter
Version:        1.9.4
Release:        1.6
Summary:        Network performance meter for the UDP, TCP, SCTP and DCCP protocols
License:        GPL-3.0-or-later
URL:            https://www.uni-due.de/~be0001/netperfmeter/
#Git-Clone:     https://github.com/dreibh/netperfmeter.git
Source:         https://www.uni-due.de/~be0001/netperfmeter/download/%{name}-%{version}.tar.xz
Source1:        https://www.uni-due.de/~be0001/netperfmeter/download/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  lksctp-tools-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bzip2)

%description
NetPerfMeter is a network performance meter for the UDP, TCP, SCTP
and DCCP transport protocols over IPv4 and IPv6. It simultaneously
transmits bidirectional flows to an endpoint and measures the
resulting flow bandwidths and QoS. The results are written as
vector and scalar files.
The vector files can e.g. be used to create plots of the results.

%prep
%autosetup

%build
# FIXME: you should use the %%cmake macros
mkdir build && cd build
cmake .. \
    -DCMAKE_INSTALL_PREFIX=%{_prefix} \
    -DWITH_NEAT=0 \
    -DBUILD_TEST_PROGRAMS=1 \
    -DBUILD_PLOT_PROGRAMS=1
%cmake_build

%install
%cmake_install
chmod +x %{buildroot}/%{_bindir}/*

%files
%license COPYING
%doc AUTHORS ChangeLog
%{_bindir}/combinesummaries
%{_bindir}/createsummary
%{_bindir}/extractvectors
%{_bindir}/getabstime
%{_bindir}/netperfmeter
%{_bindir}/runtimeestimator
%{_mandir}/man1/combinesummaries.1%{?ext_man}
%{_mandir}/man1/createsummary.1%{?ext_man}
%{_mandir}/man1/extractvectors.1%{?ext_man}
%{_mandir}/man1/getabstime.1%{?ext_man}
%{_mandir}/man1/netperfmeter.1%{?ext_man}
%{_mandir}/man1/runtimeestimator.1%{?ext_man}

%package pdfproctools
Summary:        PDF Processing Tools
Group:          Productivity/Networking/Diagnostic
Requires:       ghostscript
Requires:       perl >= 5.8.0
Requires:       perl-PDF-API2
Requires:       qpdf
BuildArch:      noarch

%description pdfproctools
SetPDFMetadata updates the metadata of a PDF file. In particular,
it can be used to add outlines (bookmarks) to a document.
Furthermore, it can set the document properties (e.g. author,
title, keywords, creator, producer).  PDFEmbedFonts embeds all
referenced fonts into a PDF file. Optionally, it can also linearize
the PDF file for online publication ("fast web view", "optimized").

This package contains tools for PDF file processing.

%files pdfproctools
%{_bindir}/pdfembedfonts
%{_bindir}/setpdfmetadata
%{_mandir}/man1/pdfembedfonts.1%{?ext_man}
%{_mandir}/man1/setpdfmetadata.1%{?ext_man}

%package plotting
Summary:        Network Performance Meter (plotting program)
Group:          Productivity/Networking/Diagnostic
Requires:       %{name} = %{version}
Requires:       %{name}-pdfproctools = %{version}
Requires:       R-core
BuildArch:      noarch

%description plotting
NetPerfMeter is a network performance meter for the UDP,
TCP, MPTCP, SCTP and DCCP transport protocols over IPv4 and IPv6.
It simultaneously transmits bidirectional flows to an endpoint
and measures the resulting flow bandwidths and QoS. The
results are written as vector and scalar files. The vector
files can e.g. be used to create plots of the results.

This package contains a plotting program for the results.

%files plotting
%{_bindir}/plot-netperfmeter-results
%dir %{_datadir}/netperfmeter
%{_datadir}/netperfmeter/plot-netperfmeter-results.R
%{_datadir}/netperfmeter/plotter.R
%{_mandir}/man1/plot-netperfmeter-results.1%{?ext_man}

%changelog
* Tue Jun 20 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.9.4:
  * Bugfix release
* Sat Jul 17 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.9.0
  Use different payload data patterns for Active -> Passive and Passive -> Active directions.
  Added note on SCTP usage with 192.168.122.1 interface.
  Added test script for Wireshark dissector tests.
  Enable 30s SCTP Heartbeats on control connection, to ensure PAT/NAT will keep the connection alive.
  Updated Wireshark color filter example.
  Bugfix: Make sure to deregister all flows belonging to a closed control connection.
  Improved DCCP detection.
  Commented out LK-SCTP bug work-around. It is hopefully not needed any more.
  Bugfix: fixed possibilities for race conditions reported by Helgrind.
  Bugfix: fixed UDP flow identification.
  Improved vector output.
  Bugfix: fixed improper deletion. Access to deallocated memory was possible.
  Bugfix: make sure to clear address space (Valgrind reported access to uninitialised memory).
  Bugfix: fixed handling of new flows on active side (variable was uninitialised).
  Also write time stamps into scalars.
* Mon Mar  1 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.8.7
  * Bugfix release
* Sat Jun 27 2020 Martin Hauke <mardnh@gmx.de>
- Add source verification
* Fri Jun 26 2020 Martin Hauke <mardnh@gmx.de> 
- Specfile cleanup
* Mon Nov 21 2016 Marcus Furlong <furlongm@gmail.com>
- Initial OBS Release
